==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicebus/kotlin/inputs/SqlFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicebus.kotlin.inputs

import com.pulumi.azurenative.servicebus.inputs.SqlFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a filter which is a composition of an expression and an action that is executed in the pub/sub pipeline.
 * @property compatibilityLevel This property is reserved for future use. An integer value showing the compatibility level, currently hard-coded to 20.
 * @property requiresPreprocessing Value that indicates whether the rule action requires preprocessing.
 * @property sqlExpression The SQL expression. e.g. MyProperty='ABC'
 */
public data class SqlFilterArgs(
    public val compatibilityLevel: Output<Int>? = null,
    public val requiresPreprocessing: Output<Boolean>? = null,
    public val sqlExpression: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicebus.inputs.SqlFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.servicebus.inputs.SqlFilterArgs =
        com.pulumi.azurenative.servicebus.inputs.SqlFilterArgs.builder()
            .compatibilityLevel(compatibilityLevel?.applyValue({ args0 -> args0 }))
            .requiresPreprocessing(requiresPreprocessing?.applyValue({ args0 -> args0 }))
            .sqlExpression(sqlExpression?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlFilterArgs].
 */
@PulumiTagMarker
public class SqlFilterArgsBuilder internal constructor() {
    private var compatibilityLevel: Output<Int>? = null

    private var requiresPreprocessing: Output<Boolean>? = null

    private var sqlExpression: Output<String>? = null

    /**
     * @param value This property is reserved for future use. An integer value showing the compatibility level, currently hard-coded to 20.
     */
    @JvmName("hgcltmrngpbbirjr")
    public suspend fun compatibilityLevel(`value`: Output<Int>) {
        this.compatibilityLevel = value
    }

    /**
     * @param value Value that indicates whether the rule action requires preprocessing.
     */
    @JvmName("jgxsvccxeysawyqn")
    public suspend fun requiresPreprocessing(`value`: Output<Boolean>) {
        this.requiresPreprocessing = value
    }

    /**
     * @param value The SQL expression. e.g. MyProperty='ABC'
     */
    @JvmName("tqbdksxkwemcfgsr")
    public suspend fun sqlExpression(`value`: Output<String>) {
        this.sqlExpression = value
    }

    /**
     * @param value This property is reserved for future use. An integer value showing the compatibility level, currently hard-coded to 20.
     */
    @JvmName("tcktldetyvketgpf")
    public suspend fun compatibilityLevel(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.compatibilityLevel = mapped
    }

    /**
     * @param value Value that indicates whether the rule action requires preprocessing.
     */
    @JvmName("uqgjygkwsnbaaxvl")
    public suspend fun requiresPreprocessing(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requiresPreprocessing = mapped
    }

    /**
     * @param value The SQL expression. e.g. MyProperty='ABC'
     */
    @JvmName("wktcioaedsnmbdxr")
    public suspend fun sqlExpression(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlExpression = mapped
    }

    internal fun build(): SqlFilterArgs = SqlFilterArgs(
        compatibilityLevel = compatibilityLevel,
        requiresPreprocessing = requiresPreprocessing,
        sqlExpression = sqlExpression,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicebus/kotlin/inputs/SqlFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicebus.kotlin.inputs

import com.pulumi.azurenative.servicebus.inputs.SqlFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a filter which is a composition of an expression and an action that is executed in the pub/sub pipeline.
 * @property compatibilityLevel This property is reserved for future use. An integer value showing the compatibility level, currently hard-coded to 20.
 * @property requiresPreprocessing Value that indicates whether the rule action requires preprocessing.
 * @property sqlExpression The SQL expression. e.g. MyProperty='ABC'
 */
public data class SqlFilterArgs(
    public val compatibilityLevel: Output<Int>? = null,
    public val requiresPreprocessing: Output<Boolean>? = null,
    public val sqlExpression: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.servicebus.inputs.SqlFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.servicebus.inputs.SqlFilterArgs =
        com.pulumi.azurenative.servicebus.inputs.SqlFilterArgs.builder()
            .compatibilityLevel(compatibilityLevel?.applyValue({ args0 -> args0 }))
            .requiresPreprocessing(requiresPreprocessing?.applyValue({ args0 -> args0 }))
            .sqlExpression(sqlExpression?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlFilterArgs].
 */
@PulumiTagMarker
public class SqlFilterArgsBuilder internal constructor() {
    private var compatibilityLevel: Output<Int>? = null

    private var requiresPreprocessing: Output<Boolean>? = null

    private var sqlExpression: Output<String>? = null

    /**
     * @param value This property is reserved for future use. An integer value showing the compatibility level, currently hard-coded to 20.
     */
    @JvmName("ytfqdbaymwgmmmpe")
    public suspend fun compatibilityLevel(`value`: Output<Int>) {
        this.compatibilityLevel = value
    }

    /**
     * @param value Value that indicates whether the rule action requires preprocessing.
     */
    @JvmName("qprberfygeqwbolv")
    public suspend fun requiresPreprocessing(`value`: Output<Boolean>) {
        this.requiresPreprocessing = value
    }

    /**
     * @param value The SQL expression. e.g. MyProperty='ABC'
     */
    @JvmName("uiktgvjkvlpauruh")
    public suspend fun sqlExpression(`value`: Output<String>) {
        this.sqlExpression = value
    }

    /**
     * @param value This property is reserved for future use. An integer value showing the compatibility level, currently hard-coded to 20.
     */
    @JvmName("annuuctlqepknirg")
    public suspend fun compatibilityLevel(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.compatibilityLevel = mapped
    }

    /**
     * @param value Value that indicates whether the rule action requires preprocessing.
     */
    @JvmName("rneenvsxswokephs")
    public suspend fun requiresPreprocessing(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requiresPreprocessing = mapped
    }

    /**
     * @param value The SQL expression. e.g. MyProperty='ABC'
     */
    @JvmName("smtyfhcdhymjlerj")
    public suspend fun sqlExpression(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlExpression = mapped
    }

    internal fun build(): SqlFilterArgs = SqlFilterArgs(
        compatibilityLevel = compatibilityLevel,
        requiresPreprocessing = requiresPreprocessing,
        sqlExpression = sqlExpression,
    )
}
